@@ -8,7 +8,7 @@
 #
 ################################################################################
 #
-# Copyright (c) 2002-2015 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2020 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -16,8 +16,8 @@
 
 use Devel::Tokenizer::C;
 
-$t = new Devel::Tokenizer::C TokenFunc => \&tok_code,
-                             TokenEnd  => 'PRAGMA_TOKEN_END';
+$t = Devel::Tokenizer::C->new(TokenFunc => \&tok_code,
+                              TokenEnd  => 'PRAGMA_TOKEN_END');
 
 $t->add_tokens( qw(
   pack
